==> servicecatalog-model-6.9.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerListFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterServiceBrokerListFluent<A extends ClusterServiceBrokerListFluent<A>> extends BaseFluent<A>{
  public ClusterServiceBrokerListFluent() {
  }
  
  public ClusterServiceBrokerListFluent(ClusterServiceBrokerList instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private ArrayList<ClusterServiceBrokerBuilder> items = new ArrayList<ClusterServiceBrokerBuilder>();
  private String kind;
  private ListMeta metadata;
  
  protected void copyInstance(ClusterServiceBrokerList instance) {
    instance = (instance != null ? instance : new ClusterServiceBrokerList());
  
    if (instance != null) {
        this.withApiVersion(instance.getApiVersion());
        this.withItems(instance.getItems());
        this.withKind(instance.getKind());
        this.withMetadata(instance.getMetadata());
        this.withApiVersion(instance.getApiVersion());
        this.withItems(instance.getItems());
        this.withKind(instance.getKind());
        this.withMetadata(instance.getMetadata());
      }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public A addToItems(int index,ClusterServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  
  public A setToItems(int index,ClusterServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  
  public A addToItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  
  public A addAllToItems(Collection<ClusterServiceBroker> items) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items == null) return (A)this;
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  
  public A removeAllFromItems(Collection<ClusterServiceBroker> items) {
    if (this.items == null) return (A)this;
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromItems(Predicate<ClusterServiceBrokerBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<ClusterServiceBrokerBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      ClusterServiceBrokerBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ClusterServiceBroker> buildItems() {
    return items != null ? build(items) : null;
  }
  
  public ClusterServiceBroker buildItem(int index) {
    return this.items.get(index).build();
  }
  
  public ClusterServiceBroker buildFirstItem() {
    return this.items.get(0).build();
  }
  
  public ClusterServiceBroker buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  
  public ClusterServiceBroker buildMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    for (ClusterServiceBrokerBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    for (ClusterServiceBrokerBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withItems(List<ClusterServiceBroker> items) {
    if (this.items != null) { _visitables.get("items").clear();}
    if (items != null) {this.items = new ArrayList(); for (ClusterServiceBroker item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
  }
  
  public A withItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (ClusterServiceBroker item :items){ this.addToItems(item);}} return (A) this;
  }
  
  public boolean hasItems() {
    return items != null && !items.isEmpty();
  }
  
  public ItemsNested<A> addNewItem() {
    return new ItemsNested(-1, null);
  }
  
  public ItemsNested<A> addNewItemLike(ClusterServiceBroker item) {
    return new ItemsNested(-1, item);
  }
  
  public ItemsNested<A> setNewItemLike(int index,ClusterServiceBroker item) {
    return new ItemsNested(index, item);
  }
  
  public ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  
  public ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public ItemsNested<A> editMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public ListMeta getMetadata() {
    return this.metadata;
  }
  
  public A withMetadata(ListMeta metadata) {
    this.metadata=metadata; return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceBrokerListFluent that = (ClusterServiceBrokerListFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
  
    if (!java.util.Objects.equals(items, that.items)) return false;
  
    if (!java.util.Objects.equals(kind, that.kind)) return false;
  
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  public class ItemsNested<N> extends ClusterServiceBrokerFluent<ItemsNested<N>> implements Nested<N>{
    ItemsNested(int index,ClusterServiceBroker item) {
      this.index = index;
      this.builder = new ClusterServiceBrokerBuilder(this, item);
    }
    ClusterServiceBrokerBuilder builder;
    int index;
    
    public N and() {
      return (N) ClusterServiceBrokerListFluent.this.setToItems(index,builder.build());
    }
    
    public N endItem() {
      return and();
    }
    
  
  }

}

==> servicecatalog-model-6.9.1-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerListFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterServiceBrokerListFluent<A extends ClusterServiceBrokerListFluent<A>> extends BaseFluent<A>{
  public ClusterServiceBrokerListFluent() {
  }
  
  public ClusterServiceBrokerListFluent(ClusterServiceBrokerList instance) {
    this.copyInstance(instance);
  }
  private String apiVersion;
  private ArrayList<ClusterServiceBrokerBuilder> items = new ArrayList<ClusterServiceBrokerBuilder>();
  private String kind;
  private ListMeta metadata;
  
  protected void copyInstance(ClusterServiceBrokerList instance) {
    instance = (instance != null ? instance : new ClusterServiceBrokerList());
    if (instance != null) {
          this.withApiVersion(instance.getApiVersion());
          this.withItems(instance.getItems());
          this.withKind(instance.getKind());
          this.withMetadata(instance.getMetadata());
          this.withApiVersion(instance.getApiVersion());
          this.withItems(instance.getItems());
          this.withKind(instance.getKind());
          this.withMetadata(instance.getMetadata());
        }
  }
  
  public String getApiVersion() {
    return this.apiVersion;
  }
  
  public A withApiVersion(String apiVersion) {
    this.apiVersion = apiVersion;
    return (A) this;
  }
  
  public boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  public A addToItems(int index,ClusterServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").add(index, builder); items.add(index, builder);}
    return (A)this;
  }
  
  public A setToItems(int index,ClusterServiceBroker item) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);
    if (index < 0 || index >= items.size()) { _visitables.get("items").add(builder); items.add(builder); } else { _visitables.get("items").set(index, builder); items.set(index, builder);}
    return (A)this;
  }
  
  public A addToItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  
  public A addAllToItems(Collection<ClusterServiceBroker> items) {
    if (this.items == null) {this.items = new ArrayList<ClusterServiceBrokerBuilder>();}
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
  }
  
  public A removeFromItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items == null) return (A)this;
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  
  public A removeAllFromItems(Collection<ClusterServiceBroker> items) {
    if (this.items == null) return (A)this;
    for (ClusterServiceBroker item : items) {ClusterServiceBrokerBuilder builder = new ClusterServiceBrokerBuilder(item);_visitables.get("items").remove(builder); this.items.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromItems(Predicate<ClusterServiceBrokerBuilder> predicate) {
    if (items == null) return (A) this;
    final Iterator<ClusterServiceBrokerBuilder> each = items.iterator();
    final List visitables = _visitables.get("items");
    while (each.hasNext()) {
      ClusterServiceBrokerBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ClusterServiceBroker> buildItems() {
    return this.items != null ? build(items) : null;
  }
  
  public ClusterServiceBroker buildItem(int index) {
    return this.items.get(index).build();
  }
  
  public ClusterServiceBroker buildFirstItem() {
    return this.items.get(0).build();
  }
  
  public ClusterServiceBroker buildLastItem() {
    return this.items.get(items.size() - 1).build();
  }
  
  public ClusterServiceBroker buildMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
      for (ClusterServiceBrokerBuilder item : items) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
      for (ClusterServiceBrokerBuilder item : items) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withItems(List<ClusterServiceBroker> items) {
    if (this.items != null) {
      this._visitables.get("items").clear();
    }
    if (items != null) {
        this.items = new ArrayList();
        for (ClusterServiceBroker item : items) {
          this.addToItems(item);
        }
    } else {
      this.items = null;
    }
    return (A) this;
  }
  
  public A withItems(io.fabric8.servicecatalog.api.model.ClusterServiceBroker... items) {
    if (this.items != null) {this.items.clear(); _visitables.remove("items"); }
    if (items != null) {for (ClusterServiceBroker item :items){ this.addToItems(item);}} return (A) this;
  }
  
  public boolean hasItems() {
    return this.items != null && !this.items.isEmpty();
  }
  
  public ItemsNested<A> addNewItem() {
    return new ItemsNested(-1, null);
  }
  
  public ItemsNested<A> addNewItemLike(ClusterServiceBroker item) {
    return new ItemsNested(-1, item);
  }
  
  public ItemsNested<A> setNewItemLike(int index,ClusterServiceBroker item) {
    return new ItemsNested(index, item);
  }
  
  public ItemsNested<A> editItem(int index) {
    if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public ItemsNested<A> editFirstItem() {
    if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
    return setNewItemLike(0, buildItem(0));
  }
  
  public ItemsNested<A> editLastItem() {
    int index = items.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public ItemsNested<A> editMatchingItem(Predicate<ClusterServiceBrokerBuilder> predicate) {
    int index = -1;
    for (int i=0;i<items.size();i++) { 
    if (predicate.test(items.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
    return setNewItemLike(index, buildItem(index));
  }
  
  public String getKind() {
    return this.kind;
  }
  
  public A withKind(String kind) {
    this.kind = kind;
    return (A) this;
  }
  
  public boolean hasKind() {
    return this.kind != null;
  }
  
  public ListMeta getMetadata() {
    return this.metadata;
  }
  
  public A withMetadata(ListMeta metadata) {
    this.metadata = metadata;
    return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
    return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceBrokerListFluent that = (ClusterServiceBrokerListFluent) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;
    if (!java.util.Objects.equals(items, that.items)) return false;
    if (!java.util.Objects.equals(kind, that.kind)) return false;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (items != null && !items.isEmpty()) { sb.append("items:"); sb.append(items + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  public class ItemsNested<N> extends ClusterServiceBrokerFluent<ItemsNested<N>> implements Nested<N>{
    ItemsNested(int index,ClusterServiceBroker item) {
      this.index = index;
      this.builder = new ClusterServiceBrokerBuilder(this, item);
    }
    ClusterServiceBrokerBuilder builder;
    int index;
    
    public N and() {
      return (N) ClusterServiceBrokerListFluent.this.setToItems(index,builder.build());
    }
    
    public N endItem() {
      return and();
    }
    
  
  }

}
